aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorCôme Chilliet <come.chilliet@nextcloud.com>2024-09-13 10:00:53 +0200
committerCôme Chilliet <come.chilliet@nextcloud.com>2024-12-19 14:43:21 +0100
commitc7dbe7e71c773587b71d283e341f7c2aaf938028 (patch)
treeb56fab4f206840607dec0966ca1536cde264c8a5
parentf0e10eaeed50e2b899701f289e2b2bd0407bed35 (diff)
downloadnextcloud-server-c7dbe7e71c773587b71d283e341f7c2aaf938028.tar.gz
nextcloud-server-c7dbe7e71c773587b71d283e341f7c2aaf938028.zip
fix(shares): Promote reshares into direct shares when share is deleted
Signed-off-by: Côme Chilliet <come.chilliet@nextcloud.com>
-rw-r--r--lib/private/Share20/Manager.php19
1 files changed, 13 insertions, 6 deletions
diff --git a/lib/private/Share20/Manager.php b/lib/private/Share20/Manager.php
index 063a1349b8d..cb4e54b4732 100644
--- a/lib/private/Share20/Manager.php
+++ b/lib/private/Share20/Manager.php
@@ -1032,7 +1032,8 @@ class Manager implements IManager {
return $deletedShares;
}
- protected function deleteReshares(IShare $share): void {
+ /* Promote reshares into direct shares so that target user keeps access */
+ protected function promoteReshares(IShare $share): void {
try {
$node = $share->getNode();
} catch (NotFoundException) {
@@ -1050,7 +1051,7 @@ class Manager implements IManager {
foreach ($users as $user) {
/* Skip share owner */
- if ($user->getUID() === $share->getShareOwner()) {
+ if ($user->getUID() === $share->getShareOwner() || $user->getUID() === $share->getSharedBy()) {
continue;
}
$userIds[] = $user->getUID();
@@ -1093,8 +1094,14 @@ class Manager implements IManager {
try {
$this->generalCreateChecks($child);
} catch (GenericShareException $e) {
- $this->logger->debug('Delete reshare because of exception '.$e->getMessage(), ['exception' => $e]);
- $this->deleteShare($child);
+ /* The check is invalid, promote it to a direct share from the sharer of parent share */
+ $this->logger->debug('Promote reshare because of exception ' . $e->getMessage(), ['exception' => $e, 'fullId' => $child->getFullId()]);
+ try {
+ $child->setSharedBy($share->getSharedBy());
+ $this->updateShare($child);
+ } catch (GenericShareException|\InvalidArgumentException $e) {
+ $this->logger->warning('Failed to promote reshare because of exception ' . $e->getMessage(), ['exception' => $e, 'fullId' => $child->getFullId()]);
+ }
}
}
}
@@ -1124,8 +1131,8 @@ class Manager implements IManager {
$this->dispatcher->dispatchTyped(new ShareDeletedEvent($share));
- // Delete reshares of the deleted share
- $this->deleteReshares($share);
+ // Promote reshares of the deleted share
+ $this->promoteReshares($share);
}